#!/usr/bin/python
# -*- coding: utf-8 -*-

VISUALIZATIONS_LIST = {
  "Visualizations":
  [{
        "ID": "html-simple",
        "Title": "Html: single-page",
        "Description": "@todo",
      } , {
        "ID": "html-complex",
        "Title": "Html: multi-page",
        "Description": "@todo",
      } , {
        "ID": "markdown",
        "Title": "Markdown: multi-page",
        "Description": "@todo",
      } , {
        "ID": "d3-tree",
        "Title": "D3 Dendogram",
        "Description": "@todo",
      }
  ]
}


BOOTSWATCH_THEMES = ['cerulean'  ,  'flatly' ,  'lumen' ,  'sandstone' ,   'spacelab'  ,  'yeti' , 'cosmo' ,  'darkly' ,  'paper' , 'simplex' , 'superhero' ,   'readable'  ,   'slate' ,  'united']

BOOTSWATCH_THEME_DEFAULT = "simplex"
# 'cyborg' , 'journal'
