# !/usr/bin/env python
#  -*- coding: UTF-8 -*-


##################
#
#  metadata
#
##################



__version__ = "1.1.2"

__copyright__ = "CopyRight (C) 2015-2017 by Michele Pasin"
__license__ = "GNU"
__author__ = "Michele Pasin"
__author_email__ = "michele dot pasin at gmail dot com"

USAGE = "ontodocs [options] [uri]"
VERSION = "v" + __version__

AGENT = "%s/%s" % (__name__, __version__)
